local M = {
  'hrsh7th/nvim-cmp',
  event = 'InsertEnter',
  dependencies = {
    'hrsh7th/cmp-nvim-lsp',
    'hrsh7th/cmp-buffer',
    'hrsh7th/cmp-path',
    'onsails/lspkind.nvim',
    'saadparwaiz1/cmp_luasnip',
  },
}

function M.opts()
  local cmp = require 'cmp'
  local kind_func = require('lspkind').cmp_format({})

  cmp.setup({
    -- documentation = true,
    sources = {
      { name = 'nvim_lsp' },
      { name = 'nvim_lua' },
      { name = 'buffer' },
      { name = 'path' },
      { name = 'luasnip' },
      -- { name = 'nvim_lsp_signature_help' },
    },
    formatting = {
      format = function(entry, vim_item)
        local modif = kind_func(entry, vim_item)
        -- folders don't exist on UNIX!
        modif.kind = string.gsub(modif.kind, 'Folder', 'Directory')
        return modif
      end
    },
    window = {
      -- completion = cmp.config.window.bordered(),
      -- documentation = cmp.config.window.bordered(),
    },
    mapping = cmp.mapping.preset.insert({
      ['<C-b>'] = cmp.mapping.scroll_docs(-4),
      ['<C-f>'] = cmp.mapping.scroll_docs(4),
      ['<C-Space>'] = cmp.mapping.complete({}),
      ['<C-e>'] = cmp.mapping.abort(),
      ['<CR>'] = cmp.mapping.confirm({ select = false })
    }),
    snippet = {
      expand = function(args)
        require('luasnip').lsp_expand(args.body)
      end
    }
  })
end

return M
